@@ -31,10 +31,11 @@
 #include <config.h>
 #endif
 
+#include <stdlib.h>
 #include <string.h>
 
+#include <glib/gi18n.h>
 #include <glade/glade-xml.h>
-#include <libgnome/libgnome.h>
 
 #include "gedit2.h"
 #include "gedit-mdi.h"
@@ -52,9 +53,6 @@ struct _GeditDialogGotoLine {
 	GtkWidget *entry;
 };
 
-static void goto_button_pressed (GeditDialogGotoLine * dialog);
-static GeditDialogGotoLine *dialog_goto_line_get_dialog (void);
-static void dialog_destroyed (GtkObject *obj,  void **dialog_pointer);
 
 static void
 dialog_destroyed (GtkObject *obj,  void **dialog_pointer)
@@ -68,6 +66,32 @@ dialog_destroyed (GtkObject *obj,  void **dialog_pointer)
 	}	
 }
 
+static void
+goto_button_pressed (GeditDialogGotoLine *dialog)
+{
+	const gchar *text;
+	GeditView *active_view;
+	GeditDocument *active_document;
+
+	gedit_debug (DEBUG_SEARCH, "");
+
+	active_view = GEDIT_VIEW (bonobo_mdi_get_active_view (BONOBO_MDI (gedit_mdi)));
+	g_return_if_fail (active_view);
+
+	active_document = gedit_view_get_document (active_view);
+	g_return_if_fail (active_document);
+
+	text = gtk_entry_get_text (GTK_ENTRY (dialog->entry));
+
+	if (text != NULL && text[0] != 0)
+	{
+		guint line = MAX (atoi (text) - 1, 0);		
+		gedit_document_goto_line (active_document, line);
+		gedit_view_scroll_to_cursor (active_view);
+		gtk_widget_grab_focus (GTK_WIDGET (active_view));
+	}
+}
+
 static void
 dialog_response_handler (GtkDialog *dlg, gint res_id,  GeditDialogGotoLine *dialog)
 {
@@ -131,30 +155,30 @@ dialog_goto_line_get_dialog (void)
 	GladeXML *gui;
 	GtkWindow *window;
 	GtkWidget *content;
-	GtkWidget *button;
 
 	gedit_debug (DEBUG_SEARCH, "");
 
+	window = GTK_WINDOW (gedit_get_active_window ());
+
 	if (dialog != NULL)
 	{
+		gtk_window_set_transient_for (GTK_WINDOW (dialog->dialog),
+					      GTK_WINDOW (window));
 		gtk_window_present (GTK_WINDOW (dialog->dialog));
-		gtk_widget_grab_focus (dialog->dialog);
 
 		return dialog;
 	}
 
 	gui = glade_xml_new (GEDIT_GLADEDIR "goto-line.glade2",
 			     "goto_line_dialog_content", NULL);
-
-	if (!gui) {
-		g_warning
-		    ("Could not find goto-line.glade2, reinstall gedit.\n");
+	if (!gui)
+	{
+		gedit_warning (window,
+			       MISSING_FILE,
+			       GEDIT_GLADEDIR "goto-line.glade2");
 		return NULL;
 	}
 
-	window = GTK_WINDOW (bonobo_mdi_get_active_window
-			     (BONOBO_MDI (gedit_mdi)));
-
 	dialog = g_new0 (GeditDialogGotoLine, 1);
 
 	dialog->dialog = gtk_dialog_new_with_buttons (_("Go to Line"),
@@ -166,35 +190,32 @@ dialog_goto_line_get_dialog (void)
 
 	g_return_val_if_fail (dialog->dialog != NULL, NULL);
 
-	/* Add Goto Line button */
-	button = gedit_button_new_with_stock_image (_("_Go to Line"), GTK_STOCK_JUMP_TO);
-	g_return_val_if_fail (button != NULL, NULL);
+	gtk_window_set_resizable (GTK_WINDOW (dialog->dialog), FALSE);
+	gtk_dialog_set_has_separator (GTK_DIALOG (dialog->dialog), FALSE);
 
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gedit_dialog_add_button (GTK_DIALOG (dialog->dialog),
+				 _("_Go to Line"), GTK_STOCK_JUMP_TO,
+				 GTK_RESPONSE_OK);
 
-	gtk_widget_show (button);
-
-	gtk_dialog_add_action_widget (GTK_DIALOG (dialog->dialog), 
-				      button, GTK_RESPONSE_OK);
-	
 	content = glade_xml_get_widget (gui, "goto_line_dialog_content");
 
 	dialog->entry = glade_xml_get_widget (gui, "entry");
 
-	if (!dialog->entry) {
-		g_warning (
-			_("Could not find the required widgets inside %s."),
-			"goto-line.glade2");
+	if (!dialog->entry)
+	{
+		gedit_warning (window,
+			       MISSING_WIDGETS,
+			       GEDIT_GLADEDIR "goto-line.glade2");
 		g_object_unref (gui);
 		g_free (dialog);
 		return NULL;
 	}
-	
+
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog->dialog)->vbox),
 			    content, FALSE, FALSE, 0);
 
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog->dialog), 
-			GTK_RESPONSE_OK, FALSE);
+					   GTK_RESPONSE_OK, FALSE);
 
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog->dialog),
 					 GTK_RESPONSE_OK);
@@ -213,12 +234,9 @@ dialog_goto_line_get_dialog (void)
 
 	g_object_unref (gui);
 
-	gtk_window_set_resizable (GTK_WINDOW (dialog->dialog), FALSE);
-
 	return dialog;
 }
 
-
 void
 gedit_dialog_goto_line (void)
 {
@@ -227,15 +245,8 @@ gedit_dialog_goto_line (void)
 	gedit_debug (DEBUG_SEARCH, "");
 
 	dialog = dialog_goto_line_get_dialog ();
-	if (dialog == NULL) {
-		g_warning ("Could not create the Goto Line dialog");
+	if (!dialog)
 		return;
-	}
-
-	gtk_window_set_transient_for (GTK_WINDOW (dialog->dialog),
-				      GTK_WINDOW
-				      (bonobo_mdi_get_active_window
-				       (BONOBO_MDI (gedit_mdi))));
 
 	gtk_widget_grab_focus (dialog->entry);
 
@@ -243,29 +254,3 @@ gedit_dialog_goto_line (void)
 		gtk_widget_show (dialog->dialog);
 }
 
-static void
-goto_button_pressed (GeditDialogGotoLine *dialog)
-{
-	const gchar* text;
-	GeditView* active_view;
-	GeditDocument* active_document;
-
-	gedit_debug (DEBUG_SEARCH, "");
-
-	active_view = GEDIT_VIEW (bonobo_mdi_get_active_view (BONOBO_MDI (gedit_mdi)));
-	g_return_if_fail (active_view);
-
-	active_document = gedit_view_get_document (active_view);
-	g_return_if_fail (active_document);
-
-	text = gtk_entry_get_text (GTK_ENTRY (dialog->entry));
-	
-	if (text != NULL && text [0] != 0)
-	{
-		guint line = MAX (atoi (text)- 1, 0);		
-		gedit_document_goto_line (active_document, line);
-		gedit_view_scroll_to_cursor (active_view);
-		gtk_widget_grab_focus (GTK_WIDGET (active_view));
-	}
-}
-
