@@ -33,6 +33,7 @@
 #include <config.h>
 #endif
 
+#include <errno.h>
 #include <unistd.h>  
 #include <stdio.h>
 #include <string.h>
@@ -41,10 +42,9 @@
 #include <sys/param.h>
 #include <fcntl.h>
 
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <eel/eel-vfs-extensions.h>
-
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
 
 #include "gedit-prefs-manager-app.h"
@@ -2103,50 +2103,6 @@ gedit_document_insert_text (GeditDocument *doc, gint pos, const gchar *text, gin
 	gtk_text_buffer_insert (GTK_TEXT_BUFFER (doc), &iter, text, len);
 }
 
-void 
-gedit_document_delete_text (GeditDocument *doc, gint start, gint end)
-{
-	GtkTextIter start_iter;
-	GtkTextIter end_iter;
-
-	gedit_debug (DEBUG_DOCUMENT, "");
-
-	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
-	g_return_if_fail (start >= 0);
-	g_return_if_fail ((end > start) || end < 0);
-
-	gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (doc), &start_iter, start);
-
-	if (end < 0)
-		gtk_text_buffer_get_end_iter (GTK_TEXT_BUFFER (doc), &end_iter);
-	else
-		gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (doc), &end_iter, end);
-
-	gtk_text_buffer_delete (GTK_TEXT_BUFFER (doc), &start_iter, &end_iter);
-}
-
-gchar*
-gedit_document_get_chars (GeditDocument *doc, gint start, gint end)
-{
-	GtkTextIter start_iter;
-	GtkTextIter end_iter;
-
-	gedit_debug (DEBUG_DOCUMENT, "");
-
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), NULL);
-	g_return_val_if_fail (start >= 0, NULL);
-	g_return_val_if_fail ((end > start) || (end < 0), NULL);
-
-	gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (doc), &start_iter, start);
-
-	if (end < 0)
-		gtk_text_buffer_get_end_iter (GTK_TEXT_BUFFER (doc), &end_iter);
-	else
-		gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (doc), &end_iter, end);
-
-	return gtk_text_buffer_get_slice (GTK_TEXT_BUFFER (doc), &start_iter, &end_iter, TRUE);
-}
-
 void
 gedit_document_set_max_undo_levels (GeditDocument *doc, gint max_undo_levels)
 {
@@ -2508,32 +2464,6 @@ gedit_document_find_prev (GeditDocument* doc, gint flags)
 	return gedit_document_find_again (doc, flags);
 }
 
-gboolean 
-gedit_document_get_selection (GeditDocument *doc, gint *start, gint *end)
-{
-	gboolean ret;
-	GtkTextIter iter;
-	GtkTextIter sel_bound;
-
-	gedit_debug (DEBUG_DOCUMENT, "");
-
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), FALSE);
-
-	ret = gtk_text_buffer_get_selection_bounds (GTK_TEXT_BUFFER (doc),			
-						    &iter,
-						    &sel_bound);
-
-	gtk_text_iter_order (&iter, &sel_bound);	
-
-	if (start != NULL)
-		*start = gtk_text_iter_get_offset (&iter); 
-
-	if (end != NULL)
-		*end = gtk_text_iter_get_offset (&sel_bound); 
-
-	return ret;
-}
-
 void
 gedit_document_replace_selected_text (GeditDocument *doc, const gchar *replace)
 {
@@ -2609,31 +2539,6 @@ gedit_document_replace_all (GeditDocument *doc,
 	return cont;
 }
 
-void
-gedit_document_set_selection (GeditDocument *doc, gint start, gint end)
-{
- 	GtkTextIter start_iter;
-	GtkTextIter end_iter;
-
-	gedit_debug (DEBUG_DOCUMENT, "");
-
-	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
-	g_return_if_fail (start >= 0);
-	g_return_if_fail ((end > start) || (end < 0));
-
-	gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (doc), &start_iter, start);
-
-	if (end < 0)
-		gtk_text_buffer_get_end_iter (GTK_TEXT_BUFFER (doc), &end_iter);
-	else
-		gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (doc), &end_iter, end);
-
-	gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (doc), &end_iter);
-
-	gtk_text_buffer_move_mark_by_name (GTK_TEXT_BUFFER (doc),
-					"selection_bound", &start_iter);
-}
-
 void 
 gedit_document_set_language (GeditDocument *doc, GtkSourceLanguage *lang)
 {
