@@ -143,11 +143,6 @@ gboolean	gedit_document_save_as 		(GeditDocument        *doc,
 						 const GeditEncoding  *encoding,
 						 GError              **error);
 
-gboolean	gedit_document_save_a_copy_as 	(GeditDocument        *doc,
-						 const gchar          *uri, 
-						 const GeditEncoding  *encoding,
-						 GError              **error);
-
 void	 	gedit_document_revert 		(GeditDocument *doc);
 
 gboolean	gedit_document_is_untitled 	(const GeditDocument* doc);
@@ -155,30 +150,11 @@ gboolean	gedit_document_get_modified 	(const GeditDocument* doc);
 
 gboolean	gedit_document_get_deleted	(GeditDocument *doc);
 
-gint		gedit_document_get_char_count	(const GeditDocument *doc);
-gint		gedit_document_get_line_count 	(const GeditDocument *doc);
-		
 void		gedit_document_insert_text	(GeditDocument *doc, 
 						 gint	        pos,
                                                  const gchar   *text,
                                                  gint           len);
 
-void		gedit_document_insert_text_at_cursor (GeditDocument *doc, 
-                                                 const gchar   *text,
-                                                 gint           len);
-
-gint		gedit_document_get_cursor (GeditDocument *doc);
-void		gedit_document_set_cursor (GeditDocument *doc, gint cursor);
-
-void 		gedit_document_delete_text 	(GeditDocument *doc, 
-		                                 gint start, gint end);
-
-gchar*		gedit_document_get_chars 	(GeditDocument *doc, 
-					         gint start, gint end);
-
-gboolean	gedit_document_get_selection 	(GeditDocument *doc,
-						 gint* start, gint* end);
-
 /* Multi-level Undo/Redo operations */
 void		gedit_document_set_max_undo_levels (GeditDocument *doc, 
 						    gint max_undo_levels);
@@ -215,11 +191,6 @@ gboolean	gedit_document_replace_all 	(GeditDocument *doc,
 				            	 const gchar *find, 
 						 const gchar *replace, 
 					    	 gint flags);
-guint		gedit_document_get_line_at_offset (const GeditDocument *doc, guint offset);
-
-void		gedit_document_set_selection 	(GeditDocument *doc, 
-						 gint start, 
-						 gint end);
 
 void 		gedit_document_set_language 	(GeditDocument *doc,
 						 GtkSourceLanguage *lang);
