@@ -33,12 +33,9 @@
 #include <config.h>
 #endif
 
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
+#include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs.h>
 
-#include <eel/eel-alert-dialog.h>
-
 #include "gedit2.h"
 #include "gedit-file.h"
 #include "gedit-debug.h"
@@ -74,6 +71,12 @@ static void 	 document_loading_cb 		(GeditDocument       *document,
 
 static gchar* gedit_default_path = NULL;
 
+/* type of the elements of the uris_to_open list */
+typedef struct {
+	gchar *uri;
+	gboolean create;
+} UriToLoad;
+
 /* Global variables for managing async loading */
 static gint                 num_of_uris_to_open = 0;
 static gint                 opened_uris 	= 0;
@@ -508,8 +511,7 @@ gedit_file_save_all (void)
 static gboolean
 gedit_file_revert_dialog (GeditDocument *doc)
 {
-	GtkWidget *msgbox;
-	AtkObject *obj;
+	GtkWidget *dialog;
 	gint ret;
 	gchar *name;
 	gchar *primary_msg;
@@ -595,34 +597,28 @@ gedit_file_revert_dialog (GeditDocument *doc)
 					hours);
 	}
 
-	msgbox = eel_alert_dialog_new (GTK_WINDOW (gedit_get_active_window ()),
-				       GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-				       GTK_MESSAGE_QUESTION,
-				       GTK_BUTTONS_NONE,
-				       primary_msg,
-				       secondary_msg, 
-				       NULL);
+	dialog = gtk_message_dialog_new (GTK_WINDOW (gedit_get_active_window ()),
+					 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+					 GTK_MESSAGE_QUESTION,
+					 GTK_BUTTONS_NONE,
+					 primary_msg);
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+						  secondary_msg);
 	g_free (primary_msg);
 	g_free (secondary_msg);
 
-	/* Add Cancel button */
-	gtk_dialog_add_button (GTK_DIALOG (msgbox), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 
-	/* Add Revert button */
-	gedit_dialog_add_button (GTK_DIALOG (msgbox), 
+	gedit_dialog_add_button (GTK_DIALOG (dialog), 
 			_("_Revert"), GTK_STOCK_REVERT_TO_SAVED, GTK_RESPONSE_YES);
 
-	gtk_dialog_set_default_response	(GTK_DIALOG (msgbox), GTK_RESPONSE_CANCEL);
+	gtk_dialog_set_default_response	(GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
 
-	obj = gtk_widget_get_accessible (msgbox);
-	if (GTK_IS_ACCESSIBLE (obj))
-		atk_object_set_name (obj, _("Question"));
+	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 
-	gtk_window_set_resizable (GTK_WINDOW (msgbox), FALSE);
+	ret = gtk_dialog_run (GTK_DIALOG (dialog));
 
-	ret = gtk_dialog_run (GTK_DIALOG (msgbox));
-		
-	gtk_widget_destroy (msgbox);
+	gtk_widget_destroy (dialog);
 
 	return (ret == GTK_RESPONSE_YES);
 }
@@ -853,24 +849,6 @@ gedit_file_open_from_stdin (GeditMDIChild *active_child)
 	return ret;
 }
 
-static void 
-create_new_file (const gchar *uri)
-{
-	gint ret;
-	GeditMDIChild *new_child;
-
-	new_child = gedit_mdi_child_new_with_uri (uri, NULL);
-	ret = bonobo_mdi_add_child (BONOBO_MDI (gedit_mdi), BONOBO_MDI_CHILD (new_child));
-	g_return_if_fail (ret != FALSE);
-	gedit_debug (DEBUG_COMMANDS, "Child added.");
-
-	ret = bonobo_mdi_add_view (BONOBO_MDI (gedit_mdi), BONOBO_MDI_CHILD (new_child));
-	g_return_if_fail (ret != FALSE);
-	gedit_debug (DEBUG_COMMANDS, "View added.");
-
-	gtk_widget_grab_focus (gedit_get_active_view ());
-}
-
 #define MAX_URI_IN_DIALOG_LENGTH 50
 
 static void
@@ -906,6 +884,9 @@ show_loading_dialog (GtkWindow *parent, gchar *uri, gboolean reverting)
 	gtk_window_set_position (GTK_WINDOW (loading_window), GTK_WIN_POS_CENTER_ON_PARENT);
 		
 	gtk_window_set_decorated (GTK_WINDOW (loading_window), FALSE); 
+	gtk_window_set_skip_taskbar_hint (GTK_WINDOW (loading_window), TRUE);
+	gtk_window_set_skip_pager_hint (GTK_WINDOW (loading_window), TRUE);
+
 	gtk_window_set_transient_for (GTK_WINDOW (loading_window), parent);
 
 	frame = gtk_frame_new (NULL);
@@ -1009,11 +990,14 @@ document_loading_cb (GeditDocument *document,
 		     gboolean       reverting)
 {
 	static GTimer *d_timer = NULL;
-	
+	UriToLoad *utl;
 	gchar *uri;
 	double et;
 
-	uri = (gchar*)uris_to_open->data;
+	utl = (UriToLoad *)uris_to_open->data;
+	g_return_if_fail (utl != NULL);
+
+	uri = utl->uri;
 	g_return_if_fail (uri != NULL);
 
 	if (d_timer == NULL)
@@ -1070,10 +1054,14 @@ document_loaded_cb (GeditDocument *document,
 		    const GError  *error,
 		    GeditMDIChild *new_child)
 {
+	UriToLoad *utl;
 	gchar *uri;
 	gchar *uri_to_display;
-	
-	uri = (gchar*)uris_to_open->data;
+
+	utl = (UriToLoad *)uris_to_open->data;
+	g_return_if_fail (utl != NULL);
+
+	uri = utl->uri;
 	g_return_if_fail (uri != NULL);
 
 	show_progress_bar (NULL, FALSE, FALSE);
@@ -1154,76 +1142,137 @@ document_loaded_cb (GeditDocument *document,
 
 	/* Load the next file in the uris_to_open list */
 	g_free (uri);
+	g_free (utl);
 	uris_to_open = g_slist_delete_link (uris_to_open, uris_to_open);
 
 	open_files ();
 }
 
+static gboolean
+unref_real (GSList *children)
+{
+	g_slist_foreach (children, (GFunc)g_object_unref, NULL);
+
+	return FALSE;
+}
+
+static void
+unref_not_opened_children ()
+{
+	GSList *children;
+
+	if (children_to_unref == NULL)
+		return;
+
+	children = g_slist_copy (children_to_unref);
+
+	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE,
+			 (GSourceFunc)unref_real,
+			 children,
+			 (GDestroyNotify)g_slist_free);
+}
+
+static void
+open_files_done ()
+{
+	/* Add all the views in the right order */
+	new_children = g_slist_reverse (new_children);
+
+	PROFILE (
+		g_message ("Document Loaded: %.3f", g_timer_elapsed (timer, NULL));
+	)
+
+	bonobo_mdi_add_views (BONOBO_MDI (gedit_mdi),
+			      new_children);
+
+	PROFILE (
+		g_message ("View added: %.3f", g_timer_elapsed (timer, NULL));
+	)
+
+	g_slist_free (new_children);
+	new_children = NULL;
+
+	/* Unref the children that were not opened to an error */
+	unref_not_opened_children ();
+	g_slist_free (children_to_unref);
+	children_to_unref = NULL;
+
+	if (num_of_uris_to_open > 1)
+	{
+		gedit_utils_set_status (NULL);
+		gedit_utils_flash_va (ngettext("Loaded %d file",
+					       "Loaded %d files", 
+					       opened_uris), 
+				      opened_uris);
+	}
+
+	/* Clean up temp variables */
+	num_of_uris_to_open = 0;
+	opened_uris = 0;
+	encoding_to_use = NULL;
+	line = -1;
+
+	PROFILE (
+		g_message ("Done all: %.3f", g_timer_elapsed (timer, NULL));
+		g_timer_destroy (timer);
+	)
+
+	gedit_mdi_set_state (gedit_mdi, GEDIT_STATE_NORMAL);
+
+	return;
+}
+
 static void
 open_files ()
 {
 	GeditDocument  *active_document;
-	
-	gchar          *uri;
-	gchar          *uri_to_display;
+	UriToLoad *utl;
+	gchar *uri;
+	gchar *uri_to_display;
 
 	if (uris_to_open == NULL)
-	{		
-		/* Add all the views in the right order */
-		new_children = g_slist_reverse (new_children);
-
-		PROFILE (
-			g_message ("Document Loaded: %.3f", g_timer_elapsed (timer, NULL));
-		)
-		
-		bonobo_mdi_add_views (BONOBO_MDI (gedit_mdi),
-				      new_children);
-	
-		PROFILE (
-			g_message ("View added: %.3f", g_timer_elapsed (timer, NULL));
-		)
-	
-		g_slist_free (new_children);
-		new_children = NULL;
-
-		/* Unref the children that were not opened to an error */
-		g_slist_foreach (children_to_unref, (GFunc)g_object_unref, NULL);
-		g_slist_free (children_to_unref);
-		children_to_unref = NULL;
-		
-		if (num_of_uris_to_open > 1)
-		{
-			gedit_utils_set_status (NULL);
-			gedit_utils_flash_va (ngettext("Loaded %d file",
-						       "Loaded %d files", 
-						       opened_uris), 
-					      opened_uris);
-		}
-
-		/* Clean up temp variables */
-		num_of_uris_to_open = 0;
-		opened_uris = 0;
-		encoding_to_use = NULL;
-		line = -1;
-
-		PROFILE (
-			g_message ("Done all: %.3f", g_timer_elapsed (timer, NULL));
-			g_timer_destroy (timer);
-		)
-
-		gedit_mdi_set_state (gedit_mdi, GEDIT_STATE_NORMAL);
+	{
+		/* stop recursion */
+		open_files_done ();
 		return;
 	}
-	
-	uri = (gchar*)uris_to_open->data;
+
+	utl = (UriToLoad *)uris_to_open->data;
+	g_return_if_fail (utl != NULL);
+
+	uri = utl->uri;
 	g_return_if_fail (uri != NULL);
-	
+
 	gedit_debug (DEBUG_FILE, "File name: %s", uri);
 
+	uri_to_display = gnome_vfs_format_uri_for_display (uri);
+
+	/* create children for non existing files */
+	if (utl->create)
+	{
+		GeditMDIChild *new_child;
+
+		new_child = gedit_mdi_child_new_with_uri (uri, NULL);
+		bonobo_mdi_add_child (BONOBO_MDI (gedit_mdi), BONOBO_MDI_CHILD (new_child));
+
+		new_children = g_slist_prepend (new_children, new_child);
+		opened_uris++;
+
+		gedit_utils_set_status (NULL);
+		gedit_utils_flash_va (_("Created file \"%s\""), uri_to_display);
+
+		g_free (uri_to_display);
+		g_free (uri);
+		g_free (utl);
+		uris_to_open = g_slist_delete_link (uris_to_open, uris_to_open);
+
+		open_files ();
+
+		return;
+	}
+
 	active_document = gedit_get_active_document ();
 	
-	uri_to_display = gnome_vfs_format_uri_for_display (uri);
-
 	PROFILE (
 		g_message ("URI to open: %.3f", g_timer_elapsed (timer, NULL));
 	)
@@ -1259,7 +1308,7 @@ open_files ()
 
 			g_free (uri_to_display);
 			g_free (uri);
-			 
+			g_free (utl);
 			uris_to_open = g_slist_delete_link (uris_to_open, uris_to_open);
 
 			open_files ();
@@ -1313,8 +1362,10 @@ gedit_file_open_uri_list (GSList *uri_list,
 			  gint line_pos,
 			  gboolean create)
 {
+	GSList *l;
+
 	gedit_debug (DEBUG_FILE, "");
-	
+
 	if (uri_list == NULL)
 		return TRUE;
 
@@ -1336,35 +1387,37 @@ gedit_file_open_uri_list (GSList *uri_list,
 		timer = g_timer_new ();
 	)
 
-	while (uri_list != NULL)
+	for (l = uri_list; l; l = l->next)
 	{
 		gchar *uri;
+		UriToLoad *u;
+
+		uri = gnome_vfs_make_uri_canonical ((const gchar*)l->data);
 
-		uri = gnome_vfs_make_uri_canonical ((const gchar*)uri_list->data);
-		
 		gedit_debug (DEBUG_FILE, "URI: %s", uri);
 
-		if (uri != NULL)
+		if (!uri)
 		{
-			if (!gedit_utils_uri_has_file_scheme (uri) || 
-			     gedit_utils_uri_exists (uri))
-			{
-				uris_to_open = g_slist_prepend (uris_to_open, uri);
-			}
-			else
-			{
-				if (create)
-				{
-					create_new_file (uri);
-				}
-				else
-				{
-					uris_to_open = g_slist_prepend (uris_to_open, uri);
-				}
-			}		
-		}	
-			
-		uri_list = g_slist_next (uri_list);
+			g_warning ("Could not get canonical uri\n");
+			continue;
+		}
+
+		u = g_new (UriToLoad, 1);
+
+		u->uri = uri;
+
+		if (create &&
+		    gedit_utils_uri_has_file_scheme (uri) &&
+		    !gedit_utils_uri_exists (uri))
+		{
+			u->create = TRUE;
+		}
+		else
+		{
+			u->create = FALSE;
+		}
+
+		uris_to_open = g_slist_prepend (uris_to_open, u);
 	}
 
 	uris_to_open = g_slist_reverse (uris_to_open);
