@@ -32,18 +32,17 @@
 #include <config.h>
 #endif
 
-#include <libgnomeui/libgnomeui.h>
-#include <glib/gunicode.h>
-#include <libgnome/gnome-i18n.h>
-#include <libgnomevfs/gnome-vfs.h>
-
+#include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/time.h>
 #include <fcntl.h>
-
 #include <string.h>
 
+#include <glib/gunicode.h>
+#include <glib/gi18n.h>
+#include <libgnomevfs/gnome-vfs.h>
+
 #include "gedit-utils.h"
 #include "gedit2.h"
 #include "bonobo-mdi.h"
@@ -1461,3 +1460,48 @@ gedit_utils_uri_get_dirname (const char *uri)
 
 	return res;
 }
+
+gchar *
+gedit_utils_replace_home_dir_with_tilde (const gchar *uri)
+{
+	gchar *tmp;
+	gchar *home;
+
+	g_return_val_if_fail (uri != NULL, NULL);
+
+	/* Note that g_get_home_dir returns a const string */
+	tmp = (gchar *)g_get_home_dir ();
+
+	if (tmp == NULL)
+		return g_strdup (uri);
+
+	home = g_filename_to_utf8 (tmp, -1, NULL, NULL, NULL);
+	if (home == NULL)
+		return g_strdup (uri);
+
+	if (strcmp (uri, home) == 0)
+	{
+		g_free (home);
+		
+		return g_strdup ("~");
+	}
+
+	tmp = home;
+	home = g_strdup_printf ("%s/", tmp);
+	g_free (tmp);
+
+	if (g_str_has_prefix (uri, home))
+	{
+		gchar *res;
+
+		res = g_strdup_printf ("~/%s", uri + strlen (home));
+
+		g_free (home);
+		
+		return res;		
+	}
+
+	g_free (home);
+	return g_strdup (uri);
+}
+
